package Qt::Gui::QPixmapCache::Key;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QPixmapCache::Key
# file     : QtGui/qpixmapcache.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_01';


# FIXME: operator overload



1;

=head1 NAME

Qt::Gui::QPixmapCache::Key

=head1 PUBLIC METHODS

=over

=item    QPixmapCache::Key()

=item    QPixmapCache::Key(const QPixmapCache::Key & other)

=item    ~Key()

=item   bool operator!=(const QPixmapCache::Key & key)

=item   QPixmapCache::Key & operator=(const QPixmapCache::Key & other)

=item   bool operator==(const QPixmapCache::Key & key)


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
