package Qt::Gui::QWidgetAction;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QWidgetAction
# file     : QtGui/qwidgetaction.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_01';
our $ISA     = qw/QAction/;


# FIXME: operator overload



1;

=head1 NAME

Qt::Gui::QWidgetAction

=head1 PUBLIC METHODS

=over

=item    QWidgetAction(QObject * parent)

=item    ~QWidgetAction()

=item   QWidget * defaultWidget()

=item   void releaseWidget(QWidget * widget)

=item   QWidget * requestWidget(QWidget * parent)

=item   void setDefaultWidget(QWidget * w)


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
