package Qt::Gui::QMouseEventTransition;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QMouseEventTransition
# file     : QtGui/qmouseeventtransition.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_01';


# FIXME: operator overload



1;

=head1 NAME

Qt::Gui::QMouseEventTransition

=head1 PUBLIC METHODS

=over

=item    QMouseEventTransition(QState * sourceState = 0)

=item    QMouseEventTransition(QState * sourceState)

=item    QMouseEventTransition(QObject * object, QEvent::Type type, Qt::MouseButton button, QState * sourceState = 0)

=item    QMouseEventTransition(QObject * object, QEvent::Type type, Qt::MouseButton button, QState * sourceState)

=item    ~QMouseEventTransition()

=item   Qt::MouseButton button()

=item   QPainterPath hitTestPath()

=item   void setButton(Qt::MouseButton button)

=item   void setHitTestPath(const QPainterPath & path)


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
