package Qt::Gui::QTextInlineObject;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QTextInlineObject
# file     : QtGui/qtextlayout.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_01';


# FIXME: operator overload



1;

=head1 NAME

Qt::Gui::QTextInlineObject

=head1 PUBLIC METHODS

=over

=item    QTextInlineObject()

=item    QTextInlineObject(int i, QTextEngine * e)

=item   qreal ascent()

=item   qreal descent()

=item   QTextFormat format()

=item   int formatIndex()

=item   qreal height()

=item   bool isValid()

=item   QRectF rect()

=item   void setAscent(qreal a)

=item   void setDescent(qreal d)

=item   void setWidth(qreal w)

=item   Qt::LayoutDirection textDirection()

=item   int textPosition()

=item   qreal width()


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
