package Qt::Gui::QSplashScreen;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QSplashScreen
# file     : QtGui/qsplashscreen.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_01';
our $ISA     = qw/QWidget/;


# FIXME: operator overload



1;

=head1 NAME

Qt::Gui::QSplashScreen

=head1 PUBLIC METHODS

=over

=item    ~QSplashScreen()

=item   void clearMessage()

=item   void finish(QWidget * w)

=item   const QPixmap pixmap()

=item   void repaint()

=item   void setPixmap(const QPixmap & pixmap)

=item   void showMessage(const QString & message, int alignment, const QColor & color = Qt::black)

=item   void showMessage(const QString & message, int alignment, const QColor & color)

=item   void showMessage(const QString & message, int alignment = Qt::AlignLeft, const QColor & color = Qt::black)

=item   void showMessage(const QString & message, int alignment, const QColor & color = Qt::black)


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
