package Qt::Gui::QTextTableCell;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QTextTableCell
# file     : QtGui/qtexttable.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_01';


# FIXME: operator overload



1;

=head1 NAME

Qt::Gui::QTextTableCell

=head1 PUBLIC METHODS

=over

=item    QTextTableCell()

=item    QTextTableCell(const QTextTableCell & o)

=item    ~QTextTableCell()

=item   QTextFrame::iterator begin()

=item   int column()

=item   int columnSpan()

=item   QTextFrame::iterator end()

=item   QTextCursor firstCursorPosition()

=item   int firstPosition()

=item   QTextCharFormat format()

=item   bool isValid()

=item   QTextCursor lastCursorPosition()

=item   int lastPosition()

=item   bool operator!=(const QTextTableCell & other)

=item   QTextTableCell & operator=(const QTextTableCell & o)

=item   bool operator==(const QTextTableCell & other)

=item   int row()

=item   int rowSpan()

=item   void setFormat(const QTextCharFormat & format)

=item   int tableCellFormatIndex()


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
