package Qt::Gui::QPaintEngineState;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QPaintEngineState
# file     : QtGui/qpaintengine.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_01';


# FIXME: operator overload



1;

=head1 NAME

Qt::Gui::QPaintEngineState

=head1 PUBLIC METHODS

=over

=item   QBrush backgroundBrush()

=item   Qt::BGMode backgroundMode()

=item   QBrush brush()

=item   bool brushNeedsResolving()

=item   QPointF brushOrigin()

=item   Qt::ClipOperation clipOperation()

=item   QPainterPath clipPath()

=item   QRegion clipRegion()

=item   QPainter::CompositionMode compositionMode()

=item   QFont font()

=item   bool isClipEnabled()

=item   QMatrix matrix()

=item   qreal opacity()

=item   QPainter * painter()

=item   QPen pen()

=item   bool penNeedsResolving()

=item   QTransform transform()


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
